import { AvatarGroupProps } from '@mui/material/AvatarGroup';
import { IUserInfo } from '../models';
/** The props type of [[`AudienceGroupContainer`]]. */
export interface IAudienceGroup extends Omit<AvatarGroupProps, 'onClick' | 'children'> {
    /**
     *   Users list.
     *
     *```
     *export interface IUserInfo {
     *      id: string;
     *      email: string;
     *      firstName: string;
     *      lastName: string;
     *      avatar: string;
     *      status?: string;
     *      backgroundColor?: string;
     *      textColor?: string;
     *      disabled?: boolean;
     *      'data-testid'?: string;
     *}
     * ```
     */
    users: ReadonlyArray<IUserInfo>;
    /**
     * loading state. If true, the component will display a skeleton loader.
     */
    loading?: boolean;
    /**
     *  Mapping of statuses to colors used for the status badges. You can define your own custom status strings that you want to use or use the presets. Colors support SX shorthand.
     *
     * @default { available: 'success.light', away: 'grey.300', offline: 'error.main' }
     */
    statusMapping?: {
        [key: string]: string;
    };
    /**
     *  Background color used for the overflow menu.
     *
     * Default: `theme.vars.palette.background.paper`
     */
    menuBackgroundColor?: string;
    /**
     *  Text color used for the names in the overflow menu.
     *
     * @default theme.vars.palette.text.primary
     */
    menuTextColor?: string;
    /**
     *  Callback function triggered when an individual avatar is clicked.
     */
    onClick?: (user: IUserInfo) => void;
    /**
     *  Quick setting the size of the avatars on the outer place,
     *  the value can be small(24px x 24px), medium(32px x 32px) or large(40px x 40px)
     *  the default size is medium.
     *  @default medium
     */
    size?: 'small' | 'medium' | 'large';
    /**
     * Max avatars to show before +x.
     * @default 2
     */
    max?: number;
}
export declare const AudienceGroupContainer: (props: IAudienceGroup) => import("react/jsx-runtime").JSX.Element;
