import { CardProps } from '@mui/material/Card';
export type HexRgbColor = {
    hex: string;
    rgb: string;
    opacity: number;
};
export interface IColorPicker extends CardProps {
    /**
     * Initial color displayed, allowing hex or rgb color.
     * @default #547CDE
     */
    initialColor?: string;
    /**
     * The mode of the color picker.
     * - **'realtime'**: In this mode, the color is applied immediately when the user adjusts the hue, saturation, or inputs a color value. The cancel and apply actions are hidden.
     * - **'confirmRequired'**: In this mode, the cancel and apply actions are visible. Users can adjust the color but must click the 'Apply' button to confirm their changes.
     * @default 'confirmRequired'
     */
    mode?: 'realtime' | 'confirmRequired';
    /**
     * The eye dropper function is available only in secure contexts (HTTPS) site and chromium based browsers.
     * @default false
     */
    hideEyeDropper?: boolean;
    /**
     * A color list, accepting hex/rgb color array. E.g: ['#F4F4F4', '#005072']
     */
    savedColors?: ReadonlyArray<string>;
    /**
     * Callback when clicking plus icon to add new color to color list
     */
    onSavedColorAdd?: (color: string) => void;
    /**
     * Callback when right clicking to delete color from color list
     */
    onSavedColorDelete?: (color: string) => void;
    /**
     * Callback when applying the color
     * In `realtime` mode, it will be triggered frequently during user adjusts the hue, saturation, or inputs a color value.
     * In `confirmRequired` mode, it will be triggered only when user clicks the apply button.
     */
    onColorChanged?: (color: HexRgbColor) => void;
    /**
     * Callback when clicking cancel button
     */
    onCancel?: () => void;
    /**
     * The text of apply button
     * @default Apply
     */
    applyButtonLabel?: string;
}
