import { StackProps } from '@mui/material/Stack';
import { OptionType } from '../models';
/** The type of the value of a condition */
export type ICondition = {
    /**
     *  The identifier of this condition
     */
    id: string;
    /**
     *  The value of the selected andor
     */
    andor?: 'and' | 'or';
    /**
     *  The value of the selected field
     */
    field: string;
    /**
     *  The value of the selected operator
     */
    operator: string;
    /**
     *  The value of the input box
     */
    value: string;
};
/** The props of the component ConditionalFilter */
export interface IConditionalFilter extends Partial<Omit<ICondition, 'id'>>, Omit<StackProps, 'onChange'> {
    /**
     *  The identifier of this condition
     */
    id: string;
    /**
     *  The index of the a condition
     */
    index?: number;
    /**
     * The options of the field selection
     *
     * ```
     * export interface OptionType {
     *  label: string | ReactNode;
     *  value: string;
     *  disabled?: boolean;
     *  [key: string]: any;
     * }
     *
     * ```
     *
     */
    fieldOptions: ReadonlyArray<OptionType>;
    /**
     * The options of the operator selection
     *
     * ```
     * export interface OptionType {
     *  label: string | ReactNode;
     *  value: string;
     *  disabled?: boolean;
     *  [key: string]: any;
     * }
     *
     * ```
     *
     */
    operatorOptions: ReadonlyArray<OptionType>;
    /**
     * Callback function when any filter element changed
     *
     * ```
     * export type ICondition = {
     *  id: string;
     *  andor?: 'and' | 'or';
     *  field: string;
     *  operator: string;
     *  value: string;
     * }
     *
     * ```
     */
    onChange: (row: ICondition) => void;
    /**
     * Callback function when delete one row of the conditional filters
     */
    onDelete: (id: string) => void;
}
export declare const ConditionalFilter: (props: IConditionalFilter) => import("react/jsx-runtime").JSX.Element;
