import { CardProps } from '@mui/material/Card';
import { ICondition, IConditionalFilter } from '../ConditionalFilter.container';
/** The props of the component FilterCard */
export interface IFilterCard extends Omit<CardProps, 'onChange'>, Pick<IConditionalFilter, 'fieldOptions' | 'operatorOptions'> {
    /**
     * The default value of the conditional filter
     *
     * ```
     * export type ICondition = {
     *  id: string;
     *  andor?: 'and' | 'or';
     *  field: string;
     *  operator: string;
     *  value: string;
     * }
     *
     * ```
     *
     */
    defaultConditions?: ReadonlyArray<ICondition>;
    /**
     *  The function used to handle the returns when any filter element been changed
     *
     * ```
     * export type ICondition = {
     *  id: string;
     *  andor?: 'and' | 'or';
     *  field: string;
     *  operator: string;
     *  value: string;
     * }
     *
     * ```
     *
     */
    onChange: (conditions: ICondition[]) => void;
    /**
     *  The function triggered when the 'Delete filter' button been clicked
     */
    onDelete: () => void;
}
export declare const FilterCard: (props: IFilterCard) => import("react/jsx-runtime").JSX.Element;
