import { UseControllerProps } from 'react-hook-form';
import type { OptionType } from '../models';
export type SupportedComponent = 'text' | 'select' | 'checkbox' | 'radio' | 'switch';
export type FormField = {
    /**
     * Form field id
     */
    id: string;
    /**
     * Form field label
     */
    label: string;
    /**
     * Form field name
     */
    name: string;
    /**
     * Component type to display, can be text' | 'select' | 'checkbox' | 'radio' | 'switch';
     */
    type: SupportedComponent;
    /**
     * Component options, select and radio will need this property.
     */
    options?: ReadonlyArray<OptionType>;
    /**
     * Component rules for the field
     */
    rules?: UseControllerProps['rules'];
    /**
     *  Props passed in for related component
     */
    properties?: Record<string, any>;
};
