import React from 'react';
import { StackProps } from '@mui/material/Stack';
/** The props type of [[`EmptyState`]]. */
export interface IEmptyState extends StackProps {
    /**
     * The size of the component.
     * `small` is equivalent to the dense styling.
     * `medium` is used for larger screen, such as Table, Error page. `small` is used for smaller component, such as Card.
     * @default 'medium'
     */
    size?: 'small' | 'medium';
    /**
     * The Icon element displayed on the top of component. It could be an Icon or an image.
     */
    icon?: React.ReactNode;
    /**
     * The header of the component.
     */
    header: string | React.ReactNode;
    /**
     * The description for additional information.
     */
    description?: string | React.ReactNode;
    /**
     *  Action buttons for empty state component.
     */
    actions?: ReadonlyArray<React.ReactElement>;
}
/** The props type of [[`EmptyStateComponent`]]. */
export interface IEmptyStateComponent extends Partial<IEmptyState> {
    iconComponent?: React.ReactNode;
    headerComponent?: React.ReactNode;
    descriptionComponent?: React.ReactNode;
    actionComponent?: React.ReactNode;
}
/**
 * @param {IEmptyState} props - provides the properties fo React component
 * @return {ReactNode} - provides the react component to be ingested
 **/
export declare const EmptyState: (props: IEmptyState) => import("react/jsx-runtime").JSX.Element;
