import { INumberFormatterContext } from './types';
/**
 * React Context to store the configuration of the NumberFormatter and provide
 * a function to update the settings.
 */
export declare const NumberFormatterContext: import("react").Context<{
    options: INumberFormatterContext;
    setOptions: React.Dispatch<React.SetStateAction<INumberFormatterContext>>;
}>;
/**
 * A utility component that allows you to specify default configuration
 * for all NumberFormatter component children.
 */
export declare const NumberFormatterContextProvider: React.FC<React.PropsWithChildren<{
    defaultProps?: INumberFormatterContext;
}>>;
/**
 * A hook that returns the current configuration of the NumberFormatterContext and
 * a function to modify that configuration.
 */
export declare const useNumberFormatterContext: () => {
    options: INumberFormatterContext;
    setOptions: React.Dispatch<React.SetStateAction<INumberFormatterContext>>;
};
/**
 * A hook that returns several utility components, including a NumberFormatterContextProvider
 * and two components (Menu or Dialog) that can be used to configure the settings in the
 * ContextProvider.
 */
export declare const useNumberFormatter: () => {
    NumberFormatterDialog: import("react").FC<Pick<import("..").DialogProps, "sx" | "title" | "open" | "onClose">>;
    NumberFormatterMenu: import("react").FC<import("@mui/material").MenuProps & {
        draggable?: boolean;
    }>;
    NumberFormatProvider: import("react").FC<import("react").PropsWithChildren<{
        defaultProps?: INumberFormatterContext;
    }>>;
};
