import React from 'react';
import { Control, FieldErrors } from 'react-hook-form';
import { IPartDialog } from './PartDialog.container';
import { IPartData, IPartThumbnail } from './models';
import { TranslateFuncType } from '../util/models';
/**
 * The props type of [[`PartDialogComponent`]].
 */
export interface IPartDialogComponent extends Omit<IPartDialog, 'onSave'> {
    /**
     * Callback fired when submit form.
     */
    handleOnSubmit: React.FormEventHandler<HTMLFormElement> | undefined;
    /**
     * This object contains methods for registering components into React Hook Form.
     */
    control: Control<IPartData>;
    /**
     * An object with field errors.
     */
    errors: FieldErrors;
    /**
     * If `true`, save button is disabled.
     */
    disableSave: boolean;
    /**
     * The props type of [[`PartThumbnail`]].
     */
    thumbnailProps: IPartThumbnail;
    /**
     *  translate function
     */
    t: TranslateFuncType;
}
/**
 * @param {IPartDialogComponent} props - provides the properties fo React component
 * @return {ReactNode} - provides the react component to be ingested
 **/
export declare const PartDialogComponent: (props: IPartDialogComponent) => import("react/jsx-runtime").JSX.Element;
