import { ReactNode } from 'react';
import { DrawerProps } from '@mui/material/Drawer';
import { ChipProps } from '@mui/material/Chip';
import type { OptionType } from '../../models';
import { ICommentAuthor } from '../CommentCard';
export type ISortOption = 'date' | 'unread' | 'author' | string | undefined;
export type ISortMenuProps = {
    /**
     * sort options for sorting provided by outside
     * @default   [{ label: 'Sort by date', value: 'date' },{ label: 'Sort by unread', value: 'unread' },{ label: 'Sort by author', value: 'author' }]
     */
    sortOptions?: ReadonlyArray<OptionType>;
    /**
     * selected sort option
     */
    selectedSortOption?: string;
    onSortChanged: (sort: ISortOption | undefined) => void;
};
export type IFilterOption = 'read' | 'unread' | 'resolved' | string | undefined;
export type IPinFilterOption = 'all' | 'unread' | 'read' | string | undefined;
export type TagsOption = {
    label: string;
    value: string;
    color: ChipProps['color'];
};
export type PinFilterItem = {
    label: string;
    value: IPinFilterOption;
};
export type IFilterMenuProps = {
    /**
     * Selected filter options
     * @default []
     */
    selectedFilterOptions?: ReadonlyArray<string>;
    /**
     * Filter options to select
     * @default [{ label: 'Show unread', value: 'unread' },{ label: 'Show read', value: 'read' },{ label: 'Show resolved', value: 'resolved' }]
     */
    filterOptions?: ReadonlyArray<OptionType>;
    /**
     * Callback function triggered when the user changed selected filters.
     */
    onFilterChanged: (filters: string[]) => void;
    /**
     * Callback function triggered when the user changed pin filter.
     */
    onPinFilterChanged?: (pinFilter: IPinFilterOption | undefined) => void;
    /**
     * Selected tags filter options
     * @default []
     */
    selectedTagsFilter?: ReadonlyArray<string>;
    /**
     * Tags filter options to select
     * @default [{ label: 'decision', value: 'decision', color: 'warning'}, {label: action, value: action, color: 'info'}, { label: 'urgent', value: 'urgent', color: 'error'}]
     */
    tagsFilterOptions?: ReadonlyArray<TagsOption>;
    /**
     * Callback function triggered when the user changed tags filter.
     * @default []
     */
    onTagsFilterChanged?: (filters: string[]) => void;
    /**
     * Selected author filter options
     */
    selectedCommentAuthorFilter?: ReadonlyArray<ICommentAuthor>;
    /**
     * Author filter options to select
     * @default []
     */
    commentAuthorFilterOptions?: ReadonlyArray<ICommentAuthor>;
    /**
     * Callback function triggered when the user changed author filter.
     */
    onCommentAuthorFilterChanged?: (filters: ICommentAuthor[]) => void;
    /**
     * A custom component for extending the filtering UI.
     */
    filterExtension?: ReactNode;
    /**
     * Callback function triggered when the user resets the filter.
     */
    onFilterReset?: () => void;
};
export type ICommentFilterDrawerComponent = DrawerProps & IFilterMenuProps & ISortMenuProps & {
    mode: 'plaintext' | 'richtext';
    onFilterClose: () => void;
    filteredCommentsCount: number;
    commentsTotal: number;
};
export declare const CommentFilterDrawerComponent: React.FC<ICommentFilterDrawerComponent>;
