import { PopperProps } from '@mui/material/Popper';
import { ICommentAuthor, ICommentRichText } from '../CommentCard';
import { ICommentTextField } from './CommentInput/CommentTextField';
export type ICommentField = Partial<PopperProps> & ICommentRichText & ICommentTextField & {
    /**
     *   Information about the current user who is authoring the comment.
     *
     *```
     * export type ICommentAuthor = {
     *    id: string;
     *    firstName: string;
     *    lastName: string;
     *    avatar: string;
     *    email: string;
     *    status?: string;
     *    backgroundColor?: string;
     *    textColor?: string;
     * };
     * ```
     */
    author: ICommentAuthor;
    /**
     *  Mapping of statuses to colors used for the status badges for authors. You can define your own custom status strings that you want to use or use the presets. Colors support SX shorthand.
     *
     * @default { available: 'success.light', away: 'grey.300', offline: 'error.main' }
     */
    statusMapping?: {
        [key: string]: string;
    };
    /**
     * Indicate the comment field style
     */
    type?: 'basic' | 'popper';
};
export declare const CommentFieldContainer: React.FC<ICommentField>;
