import { ReactNode } from 'react';
export interface IDrawerNavItem {
    /**
     * The unique identifier for the navigation item.
     */
    nodeId: string;
    /**
     * The label content for the navigation item.
     */
    label?: ReactNode;
    /**
     * The icon component to display next to the label for the navigation item.
     */
    icon?: ReactNode;
    /**
     * Custom component to display on the right side of the navigation item.
     */
    action?: ReactNode;
    /**
     * Indicates whether the navigation item is disabled.
     */
    disabled?: boolean;
    /**
     * Callback function triggered when the navigation item is clicked.
     */
    onNavItemClick?: (node: IDrawerNavItem) => void;
    /**
     * The navigation items nested under this item.
     */
    items?: ReadonlyArray<IDrawerNavItem>;
    [key: string]: any;
}
export interface IDrawerContextProps {
    /**
     *  If true, the component should render the compact drawer version.
     *  @default false
     */
    condensed?: boolean;
    /**
     * 	If true, the labels of navigation items will be shown (condensed drawer only).
     * 	@default true
     */
    showCondensedLabel?: boolean;
    /**
     * The id of the currently selected navigation item.
     */
    selectedNodeId?: string;
    /**
     * Callback function triggered when a navigation item is clicked.
     */
    onNavItemClick?: (node: IDrawerNavItem) => void;
    /**
     * List of node ids to expand when the drawer initializes. If you wish to have full control over the expanded nodes, use `expanded` prop instead.
     * @default []
     */
    defaultExpanded?: ReadonlyArray<string>;
    /**
     * List of node ids that are expanded. Use this prop if you want full control over which nodes are expanded (in conjunction with `onNavItemExpanded`).
     */
    expanded?: ReadonlyArray<string>;
}
