import { ReactNode, ReactElement } from 'react';
import { StackProps } from '@mui/material/Stack';
export type IFilterSection = {
    title: string;
    content: ReactElement;
    withFiltersApplied: boolean;
    maxHeight?: number;
    expand?: boolean;
};
/** The props of the component FilterPanel */
export interface IFilterPanel extends Omit<StackProps, 'title'> {
    /**
     *  The title of the main header
     */
    title?: ReactNode;
    /**
     * The source data of this component, a custom filter section component list.
     *
     * ```
     * export type IFilterSection = {
     *   title: string;
     *   content: ReactElement;
     *   withFiltersApplied: boolean;
     *   maxHeight?: number;
     * };
     *
     * ```
     */
    filterSections: ReadonlyArray<IFilterSection>;
    /**
     *  A custom search bar component
     */
    searchBar?: ReactNode;
    /**
     *  The call back function of the close icon
     */
    onClose: () => void;
    /**
     *  A custom component shows at the bottom of this component
     */
    actionBar?: ReactNode;
    /**
     *  Specify the number of the filter sections
     */
    numberOfSections?: number;
}
export declare const FilterPanel: (props: IFilterPanel) => import("react/jsx-runtime").JSX.Element;
