type Thresholds = {
    /**
     * Value above which the number will be formatted in
     * scientific notation
     */
    above?: number;
    /**
     * Value below which the number will be formatted in
     * scientific notation
     */
    below?: number;
};
export type IBaseFormatter = {
    /**
     * the numeric value to format
     */
    children: number | string;
    /**
     * the number of digits to show after the decimal
     */
    decimalPlaces?: number;
    /**
     * show trailing zeros at the end of a decimal to pad to the specified
     * number of decimal places.
     */
    showTrailingZeros?: boolean;
};
export type IDecimalFormatter = IBaseFormatter & {
    /**
     * How to format the number ('auto' will switch between
     * standard/decimal and scientific based on the
     * scientificThresholds that are set).
     *
     * @default 'standard'
     */
    notation?: 'standard' | 'scientific';
};
export type IAutoFormatter = IBaseFormatter & {
    /**
     * How to format the number ('auto' will switch between
     * standard/decimal and scientific based on the
     * scientificThresholds that are set).
     */
    notation: 'auto';
    /**
     * Thresholds above/below which the value will be converted
     * into scientific notation. Only the magnitude of the value is
     * considered, so positive and negative numbers will be transformed
     * in the same way.
     *
     * ```
     * interface Thresholds {
     *     above?: number;
     *     below?: number;
     * }
     * ```
     *
     */
    scientificThresholds?: Thresholds;
};
/**
 * The props of the [[`NumberFormatter`]].
 */
export type INumberFormatter = IDecimalFormatter | IAutoFormatter;
/**
 * The data available through the [[`NumberFormatterContext`]].
 */
export type INumberFormatterContext = {
    /**
     * the number of digits to show after the decimal
     */
    decimalPlaces?: number;
    /**
     * How to format the number ('auto' will switch between
     * standard/decimal and scientific based on the
     * scientificThresholds that are set).
     *
     * @default 'standard'
     */
    notation?: 'auto' | 'standard' | 'scientific';
    /**
     * Thresholds above/below which the value will be converted
     * into scientific notation. Only the magnitude of the value is
     * considered, so positive and negative numbers will be transformed
     * in the same way.
     *
     * ```
     * interface Thresholds {
     *     above?: number;
     *     below?: number;
     * }
     *
     * ```
     */
    scientificThresholds?: Thresholds;
    /**
     * show trailing zeros at the end of a decimal to pad to the specified
     * number of decimal places.
     */
    showTrailingZeros?: boolean;
};
export {};
