import { TooltipProps } from '@mui/material/Tooltip';
import { ReactNode } from 'react';
import { PopoverProps } from '@mui/material/Popover';
import { IStatusBadgeProps } from '../StatusBadge';
import { ActionsBarProps } from '../common/ActionsBar';
export type ToggleTipProps = Omit<PopoverProps, 'anchorOrigin' | 'anchorPosition'> & {
    /**
     * The title of the tooltip
     * @default undefined
     * @example
     * <ToggleTip header="This is the title" />
     */
    headline?: ReactNode;
    /**
     * The Images to be displayed in the tooltip,
     * if the value is a string, it will be displayed as a single image,
     * if the value is an array, it will be displayed as a carousel
     * @default undefined
     */
    images?: ReadonlyArray<string> | string;
    /**
     * The status badge to be displayed in the tooltip,
     * that will be displayed start of header
     * Interface IStatusBadgeProps Pick<ChipProps, 'label' | 'icon' | 'clickable'> &
     * Omit<BoxProps, 'children' | 'component' | 'ref'> & {
     *   color?: AlertProps['color'];
     * }
     * @default undefined
     */
    statusBadge?: IStatusBadgeProps;
    /**
     * The main content to be displayed in the tooltip
     */
    content?: ReactNode;
    /**
     * The actions to be displayed in the tooltip
     */
    actions?: ActionsBarProps['actions'];
    /**
     * The simple pagination of the tooltip order
     * it doesn't have any functionality
     * @default undefined
     */
    pagination?: {
        total: number;
        current: number;
    };
    /**
     * Width of the tooltip, the range of the width is 352px to 448px;
     * @default 448px
     */
    width?: number;
    /**
     * If true, show close button. if is a ReactNode, show custom close button.
     * @default false
     */
    closeButton?: boolean | ReactNode;
    /**
     * Placement, The position of the tooltip relative to the reference element
     * @default 'bottom'
     */
    placement?: TooltipProps['placement'];
    /**
     * If true, show a small arrow on the ToggleTip pointing to the reference element. This only applies for center-aligned placement values: 'top', 'left', 'right', and 'bottom'
     */
    showArrow?: boolean;
};
